@@ -12,7 +12,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.052'; # VERSION
+our $VERSION = '0.053'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -100,9 +100,10 @@ sub execute {
     $self->_execute($_, $stack) for $self->archives;
     $self->result->changed if $stack->refresh->has_changed;
 
-    if ( not ($self->dryrun and $stack->has_changed) ) {
+    if ($stack->has_changed and not $self->dryrun) {
         my $message_primer = $stack->head_revision->change_details;
-        $stack->close(message => $self->edit_message(primer => $message_primer));
+        my $message = $self->edit_message(primer => $message_primer);
+        $stack->close(message => $message, committed_by => $self->username);
         $self->repos->write_index(stack => $stack);
     }
 
@@ -147,7 +148,7 @@ Pinto::Action::Add - Add a local distribution into the repository
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 AUTHOR
 
