@@ -11,7 +11,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.052'; # VERSION
+our $VERSION = '0.053'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -57,8 +57,8 @@ sub execute {
     $copy->set_property(description => $description);
 
     my $message_primer = $copy->head_revision->change_details;
-
-    $copy->close(message => $self->edit_message(primer => $message_primer));
+    my $message = $self->edit_message(primer => $message_primer);
+    $copy->close(message => $message, committed_by => $self->username);
 
     $self->repos->write_index(stack => $copy);
 
@@ -85,7 +85,7 @@ Pinto::Action::Copy - An action to create a new stack by copying another
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 AUTHOR
 
