@@ -14,7 +14,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.052'; # VERSION
+our $VERSION = '0.053'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -22,6 +22,10 @@ extends qw( Pinto::Action );
 
 #------------------------------------------------------------------------------
 
+with qw( Pinto::Role::Committable );
+
+#------------------------------------------------------------------------------
+
 has cpanm_options => (
     is      => 'ro',
     isa     => HashRef[Maybe[Str]],
@@ -87,11 +91,18 @@ sub BUILD {
 sub execute {
     my ($self) = @_;
 
-    my $stack = $self->repos->get_stack(name => $self->stack);
+    my $stack = $self->pull ? $self->repos->open_stack(name => $self->stack)
+                            : $self->repos->get_stack(name => $self->stack);
 
     do { $self->_pull($stack, $_) for $self->targets } if $self->pull;
+    $self->result->changed if $stack->refresh->has_changed;
 
-    $self->repos->write_index(stack => $stack) if $self->result->made_changes;
+    if ($self->pull and $stack->has_changed and not $self->dryrun) {
+        my $message_primer = $stack->head_revision->change_details;
+        my $message = $self->edit_message(primer => $message_primer);
+        $stack->close(message => $message, committed_by => $self->username);
+        $self->repos->write_index(stack => $stack);
+    }
 
     $self->_install($stack, $self->targets);
 
@@ -167,7 +178,7 @@ Pinto::Action::Install - Install packages from the repository
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 AUTHOR
 
