@@ -11,7 +11,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.052'; # VERSION
+our $VERSION = '0.053'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -49,14 +49,16 @@ sub execute {
     $self->notice("Merging stack $from_stack into stack $to_stack");
 
     $from_stack->merge(to => $to_stack);
+    $self->result->changed if $to_stack->refresh->has_changed;
 
-    return $self->result if $self->dryrun or not $to_stack->refresh->has_changed;
+    if ($to_stack->has_changed and not $self->dryrun) {
+        my $message_primer = $to_stack->head_revision->change_details;
+        my $message = $self->edit_message(primer => $message_primer);
+        $to_stack->close(message => $message, committed_by => $self->username);
+        $self->repos->write_index(stack => $to_stack);
+    }
 
-    $self->repos->write_index(stack => $to_stack);
-
-    $to_stack->close(message => $self->message);
-
-    return $self->result->changed;
+    return $self->result;
 }
 
 #------------------------------------------------------------------------------
@@ -78,7 +80,7 @@ Pinto::Action::Merge - Merge packages from one stack into another
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 AUTHOR
 
