@@ -17,7 +17,7 @@ use namespace::autoclean;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.052'; # VERSION
+our $VERSION = '0.053'; # VERSION
 
 #-----------------------------------------------------------------------------
 # Roles
@@ -50,13 +50,6 @@ has log_handler => (
     lazy     => 1,
 );
 
-
-has username => (
-    is       => 'rw',
-    isa      => Str,
-    default  => $ENV{USER} || $ENV{LOGIN} || $ENV{LOGNAME},
-);
-
 #-----------------------------------------------------------------------------
 
 sub _build_log_handler {
@@ -71,8 +64,7 @@ sub _build_log_handler {
                    my $msg   = $args{message};
                    my $level = uc $args{level};
                    my $now   = DateTime->now->iso8601;
-                   my $user  = $self->username;
-                   return "$now $user $level: $msg" };
+                   return "$now $level: $msg" };
 
 
     my $out = Log::Dispatch::File->new( min_level   => $self->log_level,
@@ -142,7 +134,7 @@ Pinto::Logger - Record events in the repository log file (and elsewhere).
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 METHODS
 
